aboutsummaryrefslogtreecommitdiff
path: root/tests/gcfpeek.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/gcfpeek.c')
-rw-r--r--tests/gcfpeek.c44
1 files changed, 22 insertions, 22 deletions
diff --git a/tests/gcfpeek.c b/tests/gcfpeek.c
index 3dbd12b..fcd621b 100644
--- a/tests/gcfpeek.c
+++ b/tests/gcfpeek.c
@@ -1,4 +1,4 @@
/* grecs - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it
@@ -20,7 +20,7 @@
#include <string.h>
#include <errno.h>
#include <stdlib.h>
-#include "grecs.h"
+#include "argot.h"
static void
usage(const char *arg, FILE *fp, int code)
@@ -34,9 +34,9 @@ usage(const char *arg, FILE *fp, int code)
int
set_parser(const char *arg)
{
- grecs_parser_t p = grecs_get_parser_by_type(arg);
+ argot_parser_t p = argot_get_parser_by_type(arg);
if (p) {
- grecs_parser_fun = p;
+ argot_parser_fun = p;
return 0;
}
return 1;
@@ -48,8 +48,8 @@ main(int argc, char **argv)
char *progname = argv[0];
char *path = NULL;
char *file = NULL;
- struct grecs_node *tree, *root, *node;
- int flags = GRECS_NODE_FLAG_DEFAULT;
+ struct argot_node *tree, *root, *node;
+ int flags = ARGOT_NODE_FLAG_DEFAULT;
int rc = 2;
int reduce = 0;
int match = 0;
@@ -58,7 +58,7 @@ main(int argc, char **argv)
while (--argc) {
char *arg = *++argv;
if (strcmp(arg, "-locus") == 0)
- flags |= GRECS_NODE_FLAG_LOCUS;
+ flags |= ARGOT_NODE_FLAG_LOCUS;
else if (strncmp(arg, "-delim=", 7) == 0)
flags |= arg[7];
else if (strcmp(arg, "-reduce") == 0)
@@ -66,18 +66,18 @@ main(int argc, char **argv)
else if (strcmp(arg, "-match") == 0)
match = 1;
else if (strcmp(arg, "-nodesc") == 0)
- flags &= ~GRECS_NODE_FLAG_DESCEND;
+ flags &= ~ARGOT_NODE_FLAG_DESCEND;
else if (strcmp(arg, "-nopath") == 0)
- flags &= ~GRECS_NODE_FLAG_PATH;
+ flags &= ~ARGOT_NODE_FLAG_PATH;
else if (strncmp(arg, "-type=", 6) == 0) {
if (set_parser(arg + 6))
usage(progname, stderr, 1);
} else if (strncmp(arg, "-root=", 6) == 0)
root_path = arg + 6;
else if (strcmp(arg, "-strcat") == 0)
- grecs_parser_options |= GRECS_OPTION_QUOTED_STRING_CONCAT;
+ argot_parser_options |= ARGOT_OPTION_QUOTED_STRING_CONCAT;
else if (strcmp(arg, "-stradj") == 0)
- grecs_parser_options |= GRECS_OPTION_ADJUST_STRING_LOCATIONS;
+ argot_parser_options |= ARGOT_OPTION_ADJUST_STRING_LOCATIONS;
else if (strcmp(arg, "-h") == 0)
usage(progname, stdout, 0);
else if (arg[0] == '-')
@@ -94,14 +94,14 @@ main(int argc, char **argv)
if (!file || !path || argc)
usage(progname, stderr, 1);
- tree = grecs_parse(file);
+ tree = argot_parse(file);
if (!tree)
exit(1);
if (reduce)
- grecs_tree_reduce(tree, NULL, 0);
+ argot_tree_reduce(tree, NULL, 0);
if (root_path) {
- root = grecs_find_node(tree, root_path);
+ root = argot_find_node(tree, root_path);
if (!root) {
fprintf(stderr, "%s: node %s not found\n",
progname, root_path);
@@ -111,26 +111,26 @@ main(int argc, char **argv)
root = tree;
if (match) {
- grecs_match_buf_t match_buf;
+ argot_match_buf_t match_buf;
- for (node = grecs_match_first(root, path, &match_buf);
+ for (node = argot_match_first(root, path, &match_buf);
node;
- node = grecs_match_next(match_buf)) {
+ node = argot_match_next(match_buf)) {
rc = 0;
- grecs_print_node(node, flags, stdout);
+ argot_print_node(node, flags, stdout);
fputc('\n', stdout);
}
- grecs_match_buf_free(match_buf);
+ argot_match_buf_free(match_buf);
} else {
for (node = root; node; node = node->next) {
- node = grecs_find_node(node, path);
+ node = argot_find_node(node, path);
if (!node)
break;
rc = 0;
- grecs_print_node(node, flags, stdout);
+ argot_print_node(node, flags, stdout);
fputc('\n', stdout);
}
}
- grecs_tree_free(tree);
+ argot_tree_free(tree);
exit(rc);
}
@@ -1,4 +1,4 @@
-/* grecs - Gray's Extensible Configuration System
+/* argot - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it

Return to:

Send suggestions and report system problems to the System administrator.